@@ -43,32 +43,3 @@ STOP_INDICATORS = [
 # current working directory.
 OUTFILE = 'generated.html'
 
-# You normally don't need to modify these defaults.
-HTMLSTART = '''
-<?xml version="1.0" encoding="UTF-8"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
-"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
-<html>
-  <head>
-    <title>Generated list of tag-eggs</title>
-  </head>
-  <body>
-    <h1>Generated list of tag-eggs</h1>
-    <p>Last generated on <strong>%(date)s</strong></p>
-    <p>See overview of <a href="#latest">latest versions</a> at the
-       bottom of this page</p>
-    <ul>
-'''
-HTMLEND = '''
-    </ul>
-%(latest_versions)s
-  </body>
-</html>
-'''
-ENTRY = '''
-      <li>
-        <a href="%(url)s#egg=%(name)s-%(tag)s">
-          %(name)s-%(tag)s
-        </a>
-      </li>
-'''
