@@ -213,13 +213,20 @@ def main(defaults_file=None, specific_outfile=None):
             update_latest(latest, tag, name, url)
             entries.append(dict(tag=tag, name=name, url=url))
 
+    content = template.render(today=today,
+                              entries=entries,
+                              latest=latest)
+
+    # Create tempfile
+    handle, outfile_name = mkstemp(suffix='.html', prefix='taglist')
+    logger.debug("Writing to tempfile %s", outfile_name)
+    open(outfile_name, 'w').write(content)
+
     target = os.path.join(os.getcwd(), OUTFILE)
     if specific_outfile:
         # For overriding from buildout.
         target = specific_outfile
-    content = template.render(today=today,
-                              entries=entries,
-                              latest=latest)
-    open(target, 'w').write(content)
+
+    shutil.move(outfile_name, target)
     os.chmod(target, 0644)
     logger.info("Generated list written to %s", target)
